@@ -5,5 +5,11 @@ pub use crate::changesets::Changesets;
 pub use crate::error::{ChangesetParseError, ExplorerError, VersionParseError};
 pub use crate::package::{AsPackageGraph, Package, PackageGraph};
 pub use crate::package_manager::PackageManager;
+pub use crate::plugin::{Plugin, PluginContext, PluginManager, PluginProxy, PluginRegistrar};
 pub use crate::semantic::Semantic;
-pub use crate::version::{Version, VersionValue, Versioned};
+pub use crate::util::ToBox;
+pub use crate::version::{Version, VersionEditor, VersionMod, Versioned};
+pub use crate::DEFAULT_PACKAGE_DIR;
+
+#[cfg(feature = "derive")]
+pub use mol_derive::ToBox;
